@@ -1241,8 +1241,10 @@ def run_command(
 
     # invoke the command
     try:
-        command.__cmd_info__['call'](kwargs)
-        return 0
+        rv = command.__cmd_info__['call'](kwargs)
+        if rv is None:
+            return 0
+        return rv
     except Exception as e:
         logger.exception(f"Error while running command '{command_name}': {e}")
         subparser.print_help()
