@@ -13,6 +13,7 @@ import pathlib
 from typing import Any, Callable, Dict, Generator, Iterable, Optional, Pattern, Union
 
 from ptutils.io import get_loader, get_saver, load_txt, save_txt
+from ptutils.encoding import HAVE_YAML, register_yaml_type
 from ptutils.globbing import get_subdirs, get_subfiles
 from ptutils.text import strip_line_ending
 from ptutils.undefined import UNDEFINED, is_defined
@@ -749,3 +750,12 @@ class FolderSet:
             f"Object '{name}' found in directory '{self._root}' "
             "is neither a file nor a directory."
         )
+
+
+# =======================================================================================================================
+# Helpers: yaml encoding/decoding of file/folder/path classes
+# =======================================================================================================================
+if HAVE_YAML:
+    register_yaml_type(Folder, lambda folder: str(folder), lambda text: Folder(text))
+    register_yaml_type(File,   lambda file:   str(file),   lambda text: File(text))  # noqa: E272
+    register_yaml_type(Path,   lambda path:   str(path),   lambda text: Path(text))  # noqa: E272
